import { __decorate } from "tslib";
import { Component } from 'vue-property-decorator';
import { getRenderer, resolveSafePropsFromConfig, } from 'handie-vue';
import { DialogViewStructuralWidget } from 'handie-vue/dist/widgets';
import { isOpenerInlineObjectView } from './helper';
let FormDialogViewWidget = class FormDialogViewWidget extends DialogViewStructuralWidget {
    get dialogTitle() {
        const { title, moduleLabel } = this.config;
        if (title) {
            return title;
        }
        return moduleLabel
            ? `${isOpenerInlineObjectView(this.$$view.getOpener()) ? '修改' : '新增'}${moduleLabel}`
            : '';
    }
    initFormDialogViewContextEvents() {
        const opener = this.$$view.getOpener();
        const callback = () => {
            if (opener.getView().category === 'list') {
                opener.reload();
            }
            else if (isOpenerInlineObjectView(opener)) {
                opener.getParent().reload();
            }
            else {
                opener.emit(`dialog-view-submit.${`${opener.getId()}:${[
                    this.$$module.getModuleName(),
                    this.$$view.getView().name,
                ].join('-')}`}`, this.value);
            }
            this.closeDialog();
        };
        this.on('submit', () => {
            this.$$view.setBusy(true);
            if (isOpenerInlineObjectView(opener)) {
                this.$$view
                    .update(this.value, callback, message => this.$$app.error(message))
                    .finally(() => this.$$view.setBusy(false));
            }
            else {
                this.$$view
                    .insert(this.value, callback, message => this.$$app.error(message))
                    .finally(() => this.$$view.setBusy(false));
            }
        });
    }
    render(h) {
        return this.renderDialog({
            className: this.getStyleClassName('FormDialogViewWidget'),
            actionBarClassName: this.getStyleClassName('FormDialogViewWidget-actionBar'),
            actionText: { submitActionText: '确定' },
            children: [
                h(getRenderer('FormRenderer'), {
                    props: {
                        fields: this.fields,
                        value: this.value,
                        validation: this.validation,
                        config: Object.assign({ formControlLabelWidth: 90, formControlSize: 'small' }, resolveSafePropsFromConfig(this.config, ['moduleLabel'])),
                    },
                    on: { change: this.onFieldValueChange },
                }, this.$slots.default),
            ],
        });
    }
    created() {
        this.setStyleClassNames(this.$style);
        this.initFormDialogViewContextEvents();
    }
};
FormDialogViewWidget = __decorate([
    Component
], FormDialogViewWidget);
export default FormDialogViewWidget;
